@@ -10,18 +10,13 @@ class PrincipalServer:
     __address: str
     __port: int
     __connection: Connection
-    __query_protocol: int
-    __server_entry_prefix: bytes
 
-    def __init__(self, address: str, port: int, query_protocol: int,
-                 network_protocol: int = socket.SOCK_DGRAM, server_entry_prefix: bytes = b''):
+    def __init__(self, address: str, port: int, network_protocol: int = socket.SOCK_DGRAM):
         self.__address = address
         self.__port = port
-        self.__query_protocol = query_protocol
         self.__connection = Connection(self.__address, self.__port, network_protocol)
-        self.__server_entry_prefix = server_entry_prefix
 
-    def __parse_data(self, data: bytes) -> list:
+    def __parse_data(self, data: bytes, server_entry_prefix: bytes) -> list:
         servers = []
 
         if not data.startswith(b'\xff' * 4 + b'getserversResponse'):
@@ -31,8 +26,8 @@ class PrincipalServer:
         Some 3rd party implementations of the protocol prefix every server entry with the same
         byte sequence (CoD4 X for example) => remove the provided prefix before parsing
         """
-        if self.__server_entry_prefix != b'':
-            data = data.replace(self.__server_entry_prefix, b'')
+        if server_entry_prefix != b'':
+            data = data.replace(server_entry_prefix, b'')
 
         # Server is represented as six byte sequences, separated by backslashes
         raw_entries = [entry for entry in data.split(b'\\') if len(entry) == 6]
@@ -49,11 +44,18 @@ class PrincipalServer:
 
         return servers
 
-    def get_servers(self, keywords: str = 'full empty', timeout: float = 1.0) -> List[Server]:
+    def get_servers(self, query_protocol: int, game_name: str = '', keywords: str = 'full empty',
+                    server_entry_prefix: bytes = b'', timeout: float = 1.0) -> List[Server]:
         self.__connection.set_timeout(timeout)
 
-        command = f'getservers {self.__query_protocol} {keywords}'
+        # Build command/packet string
+        command = 'getservers '
+        # Add game name if set
+        if game_name != '':
+            command += f'{game_name} '
+        # Add query protocol and keywords
+        command += f'{query_protocol} {keywords}'
 
         self.__connection.write(b'\xff' * 4 + command.encode())
         result = self.__connection.read()
-        return self.__parse_data(result)
+        return self.__parse_data(result, server_entry_prefix)
